Refactor the CollectionHTTPServer around a wsgi-style request handler.
[jelmer/calypso.git] / setup.py
index 6cd5fbf5ebc0a41b317202ad6551be3bf3f7a8e5..56db8fc2dffa7b77bd3176d8286813d43234d88f 100755 (executable)
--- a/setup.py
+++ b/setup.py
@@ -1,8 +1,8 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 #
# This file is part of Radicale Server - Calendar Server
# Copyright © 2009-2010 Guillaume Ayoub
 #
 # This library is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with Radicale.  If not, see <http://www.gnu.org/licenses/>.
+# along with Calypso.  If not, see <http://www.gnu.org/licenses/>.
 
 """
-Radicale CalDAV server
+Calypso CalDAV server
 ======================
 
-The Radicale Project is a CalDAV calendar server.  It aims to be a light
+The Calypso Project is a CalDAV calendar server.  It aims to be a light
 solution, easy to use, easy to install, easy to configure.  As a consequence,
 it requires few software dependances and is pre-configured to work
 out-of-the-box.
 
-The Radicale Project runs on most of the UNIX-like platforms (Linux, BSD,
+The Calypso Project runs on most of the UNIX-like platforms (Linux, BSD,
 MacOS X) and Windows.  It is known to work with Evolution 2.30+, Lightning 0.9+
 and Sunbird 0.9+. It is free and open-source software, released under GPL
 version 3.
 
-For further information, please visit the `Radicale Website
-<http://www.radicale.org/>`_.
+For further information, please visit the `Calypso Website
+<http://keithp.com/blogs/calypso/>`_.
 
 """
 
 import os
-from distutils.core import setup
 from distutils.command.build_scripts import build_scripts
+from setuptools import setup
 
-import radicale
-
+try:
+    from calypso import VERSION
+except ImportError, e:
+    print 'Error importing Calypso, probably dependencies are not installed'
+    print e
+    VERSION = '0.0.1'
+    print 'Assuming version %s' % VERSION
 
 # build_scripts is known to have a lot of public methods
 # pylint: disable=R0904
@@ -49,7 +54,7 @@ class BuildScripts(build_scripts):
     """Build the package."""
     def run(self):
         """Run building."""
# These lines remove the .py extension from the radicale executable
         self.mkpath(self.build_dir)
         for script in self.scripts:
             root, _ = os.path.splitext(script)
@@ -57,23 +62,24 @@ class BuildScripts(build_scripts):
 # pylint: enable=R0904
 
 
-# When the version is updated, ``radicale.VERSION`` must be modified.
+# When the version is updated, ``calypso.VERSION`` must be modified.
 # A new section in the ``NEWS`` file must be added too.
 setup(
-    name="Radicale",
-    version=radicale.VERSION,
-    description="CalDAV Server",
+    name="calypso",
+    version=VERSION,
+    description="CalDAV and CardDAV Server",
     long_description=__doc__,
-    author="Guillaume Ayoub",
-    author_email="guillaume.ayoub@kozea.fr",
-    url="http://www.radicale.org/",
-    download_url="http://www.radicale.org/src/radicale/Radicale-%s.tar.gz" % \
-        radicale.VERSION,
+    author="Keith Packard",
+    author_email="keithp@keithp.com",
+    url="http://keithp.com/blogs/calypso/",
+    download_url="https://anonscm.debian.org/cgit/calypso/calypso.git/",
     license="GNU GPL v3",
     platforms="Any",
-    packages=["radicale", "radicale.acl"],
-    provides=["radicale"],
-    scripts=["radicale.py"],
+    packages=["calypso", "calypso.acl"],
+    provides=["calypso"],
+    install_requires=["daemon","vobject"],
+    test_requires=['nose>=0.11.1'],
+    scripts=["calypso.py"],
     cmdclass={"build_scripts": BuildScripts},
     keywords=["calendar", "CalDAV"],
     classifiers=[
@@ -87,7 +93,5 @@ setup(
         "Programming Language :: Python :: 2",
         "Programming Language :: Python :: 2.5",
         "Programming Language :: Python :: 2.6",
-        "Programming Language :: Python :: 3",
-        "Programming Language :: Python :: 3.0",
-        "Programming Language :: Python :: 3.1",
+        "Programming Language :: Python :: 2.7",
         "Topic :: Office/Business :: Groupware"])
@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 #
-# This file is part of Radicale Server - Calendar Server
-# Copyright © 2009-2010 Guillaume Ayoub
+# This file is part of Calypso Server - Calendar Server
+# Copyright © 2009-2011 Guillaume Ayoub
 #
 # This library is free software: you can redistribute it and/or modify
@@ -49,7 +54,7 @@ class BuildScripts(build_scripts):
     def run(self):
         """Run building."""
-        # These lines remove the .py extension from the radicale executable
+        # These lines remove the .py extension from the calypso executable
         self.mkpath(self.build_dir)
         for script in self.scripts: